# odepy
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![Stable Docs](https://img.shields.io/badge/docs-stable-blue.svg)](https://micheleceresoli.github.io/odepy/)
[![Build Status](https://github.com/MicheleCeresoli/odepy/actions/workflows/ci.yml/badge.svg?branch=main)](https://github.com/MicheleCeresoli/odepy/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/MicheleCeresoli/odepy/branch/main/graph/badge.svg?token=ECDAU1ZURX)](https://codecov.io/gh/MicheleCeresoli/odepy)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

An extremely fast propagator for Python, in Python.
